#!/bin/bash
#############################################################################
# Purpose : Copy and apply Alfresco repo and/or share AMPs to overlay
# Author  : Thore P. C. Kragelund, Redpill Linpro
# Date    : 2014-09-30
# Package : alfresco-docker-utils-1.3.2
# Usage   : Run with name of project+instance and optional input paths
#############################################################################

function usage_error {
  echo -n "Usage: ${0##*/}"
  echo -n " <project>[:repo|share]"
  echo -n " [-f path_to_resource_files]"
  echo -n " [-t path_to_tmp_files]"
  echo
  exit 2
}

function deploy_repo_amp {
  if [ -n "$TMP_PATH" ]; then
    $SCRIPT_PATH/sudock.sh cp -v $TMP_PATH/alfresco-$ALF_PRJ-repo-*.amp $RSRC_PATH/repo-amps
  fi
  $SCRIPT_PATH/sudock.sh cp -v $RSRC_PATH/repo-amps/alfresco-$ALF_PRJ-repo-*.amp $TC_REPO_HOME/amps
  $SCRIPT_PATH/sudock.sh $ALF_HOME/bin/apply_amps.sh repo -q
  docker restart $ALF_PRJ-alf-repo
}

function deploy_share_amp {
  if [ -n "$TMP_PATH" ]; then
    $SCRIPT_PATH/sudock.sh cp -v $TMP_PATH/alfresco-$ALF_PRJ-share-*.amp $RSRC_PATH/share-amps
  fi
  $SCRIPT_PATH/sudock.sh cp -v $RSRC_PATH/share-amps/alfresco-$ALF_PRJ-share-*.amp $TC_SHARE_HOME/amps
  $SCRIPT_PATH/sudock.sh $ALF_HOME/bin/apply_amps.sh share -q
  docker restart $ALF_PRJ-alf-share
}

SCRIPT_PATH="$(dirname $(readlink -f $0))"
RSRC_PATH="$SCRIPT_PATH/resources"
ALF_PRJ="${1%%:*}"
INSTANCE="${1##*:}"
shift
while getopts f:t: OPTION; do
  case ${OPTION} in
    f)
      RSRC_PATH="$OPTARG"
      ;;
    t)
      TMP_PATH="$OPTARG"
      ;;
    \?)
      usage_error
      ;;
  esac
done

[ -z "$ALF_PRJ" ] && usage_error

ALF_HOME="/opt/alfresco/$ALF_PRJ"
TC_REPO_HOME="$ALF_HOME/tomcat-repo"
TC_SHARE_HOME="$ALF_HOME/tomcat-share"

if [ "$ALF_PRJ" == "$INSTANCE" ]; then
  deploy_repo_amp
  deploy_share_amp
else
  case $INSTANCE in
  'repo')
    deploy_repo_amp
    ;;
  'share')
    deploy_share_amp
    ;;
  *)
    echo "Unknown instance '$INSTANCE'."
    exit 2
  esac
fi
