#!/bin/bash
#############################################################################
# Purpose : Partial or total reset of the Alfresco Docker environment
# Author  : Thore P. C. Kragelund, Redpill Linpro
# Date    : 2014-09-18
# Package : alfresco-docker-utils-1.3.2
# Usage   : Run with project name and optional container names
#############################################################################

function usage_error {
  echo "Usage: ${0##*/} <project_name> [container_names]"
  exit 2
}

PRJ_NAME="$1"
[ -z "$PRJ_NAME" ] && usage_error

SCRIPT_PATH="$(dirname $(readlink -f $0))"
CNT_NAMES="logserver log-ui alf-db alf-repo alf-share alf-solr"
if [ $# -gt 1 ]; then
  CNT_NAMES="${@:2}"
fi

echo "Destroying existing containers ..."
for CNT_NAME in $CNT_NAMES; do
  CNT_NAME="${CNT_NAME%%:*}"
  docker stop $PRJ_NAME-$CNT_NAME
  docker rm $PRJ_NAME-$CNT_NAME
done

if [ $# -eq 1 ]; then
  echo "Re-installing complete overlay ..."
  $SCRIPT_PATH/sudock.sh $SCRIPT_PATH/alf_overlay_install.sh $PRJ_NAME
else
  if [ -n "$(echo $INSTANCES | grep alf-repo)" ]; then
    echo "Re-installing repo overlay ..."
    $SCRIPT_PATH/sudock.sh $SCRIPT_PATH/alf_overlay_install.sh $PRJ_NAME:repo
  fi
  if [ -n "$(echo $INSTANCES | grep alf-share)" ]; then
    echo "Re-installing share overlay ..."
    $SCRIPT_PATH/sudock.sh $SCRIPT_PATH/alf_overlay_install.sh $PRJ_NAME:share
  fi
fi

echo "Creating new containers ..."
for CNT_NAME in $CNT_NAMES; do
  CNT_CMD_OPTS="${CNT_NAME##*:}"
  CNT_NAME="${CNT_NAME%%:*}"
  CNT_RUN_CMD="$SCRIPT_PATH/alf_docker_run.sh $PRJ_NAME $CNT_NAME -d"
  if [ "$CNT_CMD_OPTS" != "$CNT_NAME" ]; then
    CNT_RUN_CMD="$CNT_RUN_CMD -o $CNT_CMD_OPTS"
  fi
  $CNT_RUN_CMD
done